@@ -128,7 +128,7 @@ define ([
                     r += tobj.preamble + '<br><br>';
                 }
 
-                // populate maxl array
+                // populate maxl array (maximum length of each column)
                 allEntries = tobj.getEntries();
                 allEntries.map(function (e) {
                     headingsentry[e.prop] = e.text;
@@ -241,19 +241,19 @@ define ([
                 entry,
                 i,
                 r;
-            console.log("miniMenu is ", mm);
-            console.log("miniMenu length is " + len);
+            // console.log("miniMenu is ", mm);
+            // console.log("miniMenu length is " + len);
             if (len > 0) {
                 r = 'Menu:&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
                 for (i = 0; i < len; i += 1) {
-                    console.log("i === " + i);
-                    console.log("Attempting to pull target " + entries[i] + " from miniMenu");
+                    // console.log("i === " + i);
+                    // console.log("Attempting to pull target " + entries[i] + " from miniMenu");
                     entry = target.pull(entries[i]);
                     if (lib.privCheck(entry.aclProfile)) {
-                        r += i + '. ' + entry.menuText + '&nbsp;&nbsp;';
+                        r += i + '.&nbsp' + entry.menuText + '&nbsp; ';
                     }
                 }
-                r += 'X. Exit/back';
+                r += 'X.&nbspExit/back';
             } else {
                 r = "To leave this page, press ENTER or click the Submit button";
             }
@@ -502,9 +502,9 @@ define ([
                     r += '<br>';
                 }
         
-                // READ-WRITE entries second
+                // WRITABLE entries second
                 len = dfo.entriesWrite ? dfo.entriesWrite.length : 0;
-                console.log("Processing " + len + " read-write dform entries");
+                console.log("Processing " + len + " writable dform entries");
                 for (i = 0; i < len; i += 1) {
                     entry = dfo.entriesWrite[i];
                     if (! entry.hasOwnProperty('size') && entry.hasOwnProperty('maxlen')) {
