@@ -246,26 +246,24 @@ define ([
             }
             if (item !== undefined) {
                 //console.log("Selected " + dfn + " menu item: " + item.name);
-                if (currentTarget.type === 'dform') {
-                    if (obj === undefined) {
-                        newObj = {};
-                    } else {
-                        newObj = $.extend({}, obj);
-                    }
-                    // Vet all writable entries
-                    len = currentTarget.entriesWrite ? currentTarget.entriesWrite.length : 0;
-                    console.log("Vetting " + len + " writable dform entries");
-                    for (i = 0; i < len; i += 1) {
-                        entry = currentTarget.entriesWrite[i];
-                        if (! mmVetEntry(i, entry.name)) {
-                            return;
-                        }
-                        newObj[entry.prop] = $('#' + entry.name).val();
-                    }
-                    if (currentTarget.rememberState) {
-                        console.log("Changing stack state to", newObj);
-                        stack.setState(newObj);
+                if (obj === undefined) {
+                    newObj = {};
+                } else {
+                    newObj = $.extend({}, obj);
+                }
+                // Vet all writable entries
+                len = currentTarget.entriesWrite ? currentTarget.entriesWrite.length : 0;
+                console.log("Vetting " + len + " writable dform entries");
+                for (i = 0; i < len; i += 1) {
+                    entry = currentTarget.entriesWrite[i];
+                    if (! mmVetEntry(i, entry.name)) {
+                        return;
                     }
+                    newObj[entry.prop] = $('#' + entry.name).val();
+                }
+                if (currentTarget.rememberState) {
+                    console.log("Changing stack state to", newObj);
+                    stack.setState(newObj);
                 }
                 stack.push(item, newObj);
             }
@@ -537,7 +535,6 @@ define ([
                 opts.resultLine = ('resultLine' in opts) ? opts.resultLine : "&nbsp";
                 opts.resultLine = (opts.resultLine === null) ? "&nbsp" : opts.resultLine;
                 opts.inputId = ('inputId' in opts) ? opts.inputId : null;
-                coreLib.displayResult(opts.resultLine);
                 // determine dform "state" (i.e. starting content of form entries)
                 if (! state) {
                     state = stack.getState();
@@ -561,6 +558,7 @@ define ([
                 if (opts.populate && populateArray.length > 0) {
                     populate.bootstrap(populateArray);
                 }
+                coreLib.displayResult(opts.resultLine);
                 // listen for user input in form
                 dformListen(dfn, state, opts.inputId);
             };
@@ -574,11 +572,16 @@ define ([
                 console.log('Entering start.dmenu with argument: ' + dmn);
                 // coreLib.clearResult();
                 stack.setFlag();
+                if (typeof opts !== 'object' || opts === null) {
+                    opts = {};
+                }
+                opts.resultLine = ('resultLine' in opts) ? opts.resultLine : "&nbsp";
+                opts.resultLine = (opts.resultLine === null) ? "&nbsp" : opts.resultLine;
                 $('#mainarea').html(dmo.source);
                 $('input[name="sel"]').val('').focus();
                 $('#' + dmn).submit(dmenuSubmitEvent(dmn));
                 $('input[name="sel"]').keydown(dmenuKeyListener(dmn));
-                coreLib.clearResult();
+                coreLib.displayResult(opts.resultLine);
             };
         }, // dmenu
 
